==> monaco-vscode-user-data-profile-service-override-8.0.4.tgz: package/vscode/src/vs/base/browser/ui/radio/radio.js <==
import { Widget } from 'vscode/vscode/vs/base/browser/ui/widget';
import { Emitter } from 'vscode/vscode/vs/base/common/event';
import './radio.css.js';
import { $ } from 'vscode/vscode/vs/base/browser/dom';
import { Button } from 'vscode/vscode/vs/base/browser/ui/button/button';
import { DisposableMap, DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';
import { getDefaultHoverDelegate } from 'vscode/vscode/vs/base/browser/ui/hover/hoverDelegateFactory';

class Radio extends Widget {
    constructor(opts) {
        super();
        this._onDidSelect = this._register(( new Emitter()));
        this.onDidSelect = this._onDidSelect.event;
        this.items = [];
        this.buttons = this._register(( new DisposableMap()));
        this.hoverDelegate = opts.hoverDelegate ?? getDefaultHoverDelegate('element');
        this.domNode = $('.monaco-custom-radio');
        this.domNode.setAttribute('role', 'radio');
        this.setItems(opts.items);
    }
    setItems(items) {
        this.buttons.clearAndDisposeAll();
        this.items = items;
        this.activeItem = this.items.find(item => item.isActive) ?? this.items[0];
        for (let index = 0; index < this.items.length; index++) {
            const item = this.items[index];
            const disposables = ( new DisposableStore());
            const button = disposables.add(( new Button(this.domNode, {
                hoverDelegate: this.hoverDelegate,
                title: item.tooltip,
                supportIcons: true,
            })));
            button.enabled = !item.disabled;
            disposables.add(button.onDidClick(() => {
                if (this.activeItem !== item) {
                    this.activeItem = item;
                    this.updateButtons();
                    this._onDidSelect.fire(index);
                }
            }));
            this.buttons.set(button, { item, dispose: () => disposables.dispose() });
        }
        this.updateButtons();
    }
    setActiveItem(index) {
        if (index < 0 || index >= this.items.length) {
            throw ( new Error('Invalid Index'));
        }
        this.activeItem = this.items[index];
        this.updateButtons();
    }
    setEnabled(enabled) {
        for (const [button] of this.buttons) {
            button.enabled = enabled;
        }
    }
    updateButtons() {
        let isActive = false;
        for (const [button, { item }] of this.buttons) {
            const isPreviousActive = isActive;
            isActive = item === this.activeItem;
            button.element.classList.toggle('active', isActive);
            button.element.classList.toggle('previous-active', isPreviousActive);
            button.label = item.text;
        }
    }
}

export { Radio };

==> monaco-vscode-user-data-profile-service-override-9.0.2.tgz: package/vscode/src/vs/base/browser/ui/radio/radio.js <==
import { Widget } from 'vscode/vscode/vs/base/browser/ui/widget';
import { Emitter } from 'vscode/vscode/vs/base/common/event';
import './radio.css.js';
import { $ } from 'vscode/vscode/vs/base/browser/dom';
import { Button } from 'vscode/vscode/vs/base/browser/ui/button/button';
import { DisposableMap, DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';
import { createInstantHoverDelegate } from 'vscode/vscode/vs/base/browser/ui/hover/hoverDelegateFactory';

class Radio extends Widget {
    constructor(opts) {
        super();
        this._onDidSelect = this._register(( new Emitter()));
        this.onDidSelect = this._onDidSelect.event;
        this.items = [];
        this.buttons = this._register(( new DisposableMap()));
        this.hoverDelegate = opts.hoverDelegate ?? this._register(createInstantHoverDelegate());
        this.domNode = $('.monaco-custom-radio');
        this.domNode.setAttribute('role', 'radio');
        this.setItems(opts.items);
    }
    setItems(items) {
        this.buttons.clearAndDisposeAll();
        this.items = items;
        this.activeItem = this.items.find(item => item.isActive) ?? this.items[0];
        for (let index = 0; index < this.items.length; index++) {
            const item = this.items[index];
            const disposables = ( new DisposableStore());
            const button = disposables.add(( new Button(this.domNode, {
                hoverDelegate: this.hoverDelegate,
                title: item.tooltip,
                supportIcons: true,
            })));
            button.enabled = !item.disabled;
            disposables.add(button.onDidClick(() => {
                if (this.activeItem !== item) {
                    this.activeItem = item;
                    this.updateButtons();
                    this._onDidSelect.fire(index);
                }
            }));
            this.buttons.set(button, { item, dispose: () => disposables.dispose() });
        }
        this.updateButtons();
    }
    setActiveItem(index) {
        if (index < 0 || index >= this.items.length) {
            throw ( new Error('Invalid Index'));
        }
        this.activeItem = this.items[index];
        this.updateButtons();
    }
    setEnabled(enabled) {
        for (const [button] of this.buttons) {
            button.enabled = enabled;
        }
    }
    updateButtons() {
        let isActive = false;
        for (const [button, { item }] of this.buttons) {
            const isPreviousActive = isActive;
            isActive = item === this.activeItem;
            button.element.classList.toggle('active', isActive);
            button.element.classList.toggle('previous-active', isPreviousActive);
            button.label = item.text;
        }
    }
}

export { Radio };
